@@ -4,8 +4,8 @@ from .hillas import (
     camera_to_shower_coordinates,
 )
 from .timing import timing_parameters
-from .leakage import leakage
-from .concentration import concentration
+from .leakage import leakage_parameters
+from .concentration import concentration_parameters
 from .statistics import descriptive_statistics
 from .morphology import (
     number_of_islands,
@@ -20,3 +20,4 @@ from .extractor import *
 from .reducer import *
 from .geometry_converter import *
 from .muon import *
+from .image_processor import ImageProcessor
