@@ -8,11 +8,14 @@ To do:
 
 """
 import numpy as np
+
+from math import erf
+from numba import vectorize, double
+
 from scipy.ndimage.filters import correlate1d
 from iminuit import Minuit
 from astropy import units as u
 from scipy.constants import alpha
-from scipy.stats import norm
 from astropy.coordinates import SkyCoord
 from functools import lru_cache
 
@@ -25,41 +28,42 @@ from ...core.traits import FloatTelescopeParameter, IntTelescopeParameter
 # ratio of the areas of the unit circle and a square of side lengths 2
 CIRCLE_SQUARE_AREA_RATIO = np.pi / 4
 
+# Sqrt of 2, as it is needed multiple times
+SQRT2 = np.sqrt(2)
 
+
+@vectorize([double(double, double, double)])
 def chord_length(radius, rho, phi):
     """
     Function for integrating the length of a chord across a circle
 
     Parameters
     ----------
-    radius: float
+    radius: float or ndarray
         radius of circle
-    rho: float
+    rho: float or ndarray
         fractional distance of impact point from circle center
-    phi: ndarray in radians
+    phi: float or ndarray in radians
         rotation angles to calculate length
 
     Returns
     -------
-    ndarray: chord length
+    float or ndarray:
+        chord length
     """
-    scalar = np.isscalar(phi)
-    phi = np.array(phi, ndmin=1, copy=False)
-
     chord = 1 - (rho ** 2 * np.sin(phi) ** 2)
     valid = chord >= 0
 
+    if not valid:
+        return 0
+
     if rho <= 1.0:
         # muon has hit the mirror
-        chord[valid] = radius * (np.sqrt(chord[valid]) + rho * np.cos(phi[valid]))
+        chord = radius * (np.sqrt(chord) + rho * np.cos(phi))
     else:
         # muon did not hit the mirror
-        chord[valid] = 2 * radius * np.sqrt(chord[valid])
+        chord = 2 * radius * np.sqrt(chord)
 
-    chord[~valid] = 0
-
-    if scalar:
-        return chord[0]
     return chord
 
 
@@ -195,6 +199,28 @@ def image_prediction(
     )
 
 
+@vectorize([double(double, double, double)])
+def gaussian_cdf(x, mu, sig):
+    """
+    Function to compute values of a given gaussians
+    cumulative distribution function (cdf)
+
+    Parameters
+    ----------
+    x: float or ndarray
+        point, at which the cdf should be evaluated
+    mu: float or ndarray
+        gaussian mean
+    sig: float or ndarray
+        gaussian standard deviation
+
+    Returns
+    -------
+    float or ndarray: cdf-value at x
+    """
+    return 0.5 * (1 + erf((x - mu) / (SQRT2 * sig)))
+
+
 def image_prediction_no_units(
     mirror_radius_m,
     hole_radius_m,
@@ -241,7 +267,7 @@ def image_prediction_no_units(
     # The weight is the integral of the ring's radial gaussian profile inside the
     # ring's width
     delta = pixel_diameter_rad / 2
-    cdfs = norm.cdf(
+    cdfs = gaussian_cdf(
         [radial_dist + delta, radial_dist - delta], radius_rad, ring_width_rad
     )
     gauss = cdfs[0] - cdfs[1]
@@ -272,6 +298,7 @@ def image_prediction_no_units(
     # circle's area and that of the square whose side is equal to the circle's
     # diameter. In any case, since in the end we do a data-MC comparison of the muon
     # ring analysis outputs, it is not critical that this value is exact.
+
     pred *= CIRCLE_SQUARE_AREA_RATIO
 
     return pred
@@ -445,7 +472,6 @@ class MuonIntensityFitter(TelescopeComponent):
         help="Oversampling for the line integration", default_value=3
     ).tag(config=True)
 
-
     def __call__(self, tel_id, center_x, center_y, radius, image, pedestal, mask=None):
         """
 
