@@ -1,7 +1,7 @@
 from ctapipe.instrument import CameraDescription
 
 
-def test_known_camera_names():
+def test_known_camera_names(camera_geometries):
     """ Check that we can get a list of known camera names """
     cams = CameraDescription.get_known_camera_names()
     assert len(cams) > 4
