@@ -1,12 +1,21 @@
 from .array import get_array_layout
 from .eventseeker import EventSeeker
-from .eventsource import EventSource, event_source
+from .eventsource import EventSource
 from .hdf5tableio import HDF5TableReader, HDF5TableWriter
 from .tableio import TableWriter, TableReader
 from .datalevels import DataLevel
+from .astropy_helpers import h5_table_to_astropy as read_table
+from .dl1writer import DL1Writer
+
+from ..core.plugins import detect_and_import_io_plugins
 
 # import event sources to make them visible to EventSource.from_url
 from .simteleventsource import SimTelEventSource
+from .dl1eventsource import DL1EventSource
+
+# import IO plugins with their event sources
+detect_and_import_io_plugins()
+
 
 __all__ = [
     "get_array_layout",
@@ -16,7 +25,9 @@ __all__ = [
     "TableReader",
     "EventSeeker",
     "EventSource",
-    "event_source",
     "SimTelEventSource",
+    "DL1EventSource",
     "DataLevel",
+    "read_table",
+    "DL1Writer",
 ]
