@@ -1,12 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from .HillasReconstructor import HillasReconstructor, Reconstructor
 from .ImPACT import ImPACTReconstructor
-from .shower_max import ShowerMaxEstimator
 
 
-__all__ = [
-    "HillasReconstructor",
-    "Reconstructor",
-    "ImPACTReconstructor",
-    "ShowerMaxEstimator",
-]
+__all__ = ["HillasReconstructor", "Reconstructor", "ImPACTReconstructor"]
