@@ -5,7 +5,7 @@ geom = CameraGeometry.from_name("LSTCam")
 
 plt.figure(figsize=(8, 3))
 plt.subplot(1, 2, 1)
-plt.imshow(geom.neighbor_matrix, origin="bottom")
+plt.imshow(geom.neighbor_matrix, origin="lower")
 plt.title("Pixel Neighbor Matrix")
 
 plt.subplot(1, 2, 2)
